### Name: sp.DIC
### Title: Calculates model DIC and associated statistics given a ggt.sp,
###   sp.lm, or bayes.geostat.exact object
### Aliases: sp.DIC
### Keywords: misc

### ** Examples

## Not run: 
##D ###########################################
##D ##          DIC for sp.lm
##D ###########################################
##D 
##D #############################
##D ##Modified predictive process
##D ##############################
##D ##Use some more observations
##D data(rf.n200.dat)
##D 
##D Y <- rf.n200.dat$Y
##D coords <- as.matrix(rf.n200.dat[,c("x.coords","y.coords")])
##D 
##D ##############################
##D ##Using unmarginalized DIC
##D ##to assess number of knots
##D ##############################
##D m.1 <- sp.lm(Y~1, coords=coords, knots=c(5, 5, 0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100, sp.effects=TRUE)
##D 
##D print(sp.DIC(m.1, start=100, thin=2, DIC.marg=TRUE, DIC.unmarg=TRUE))
##D 
##D m.2 <- sp.lm(Y~1, coords=coords, knots=c(7, 7, 0),
##D              starting=list("phi"=0.6,"sigma.sq"=1, "tau.sq"=1),
##D              sp.tuning=list("phi"=0.01, "sigma.sq"=0.05, "tau.sq"=0.05),
##D              priors=list("phi.Unif"=c(0.3, 3), "sigma.sq.IG"=c(2, 1),
##D                "tau.sq.IG"=c(2, 1)),
##D              cov.model="exponential",
##D              n.samples=1000, verbose=TRUE, n.report=100, sp.effects=TRUE)
##D 
##D print(sp.DIC(m.2, start=100, thin=2, DIC.marg=TRUE, DIC.unmarg=TRUE))
##D 
##D ###########################################
##D ##    DIC for bayes.geostat.exact
##D ###########################################
##D data(FORMGMT.dat)
##D 
##D n = nrow(FORMGMT.dat)
##D p = 5 ##an intercept an four covariates
##D 
##D n.samples <- 10
##D 
##D coords <- cbind(FORMGMT.dat$Longi, FORMGMT.dat$Lat)
##D 
##D phi <- 3/0.07
##D 
##D beta.prior.mean <- rep(0, times=p)
##D beta.prior.precision <- matrix(0, nrow=p, ncol=p)
##D 
##D alpha <- 1/1.5
##D 
##D sigma.sq.prior.shape <- 2.0
##D sigma.sq.prior.rate <- 10.0
##D 
##D ##With covariates
##D m.3 <-
##D   bayes.geostat.exact(Y~X1+X2+X3+X4, data=FORMGMT.dat,
##D                       n.samples=n.samples,
##D                       beta.prior.mean=beta.prior.mean,
##D                       beta.prior.precision=beta.prior.precision,
##D                       coords=coords, phi=phi, alpha=alpha,
##D                       sigma.sq.prior.shape=sigma.sq.prior.shape,
##D                       sigma.sq.prior.rate=sigma.sq.prior.rate,
##D                       sp.effects=FALSE)
##D 
##D print(sp.DIC(m.3, DIC.marg=TRUE, DIC.unmarg=FALSE))
##D 
##D ##Without covariates
##D p <- 1 ##intercept only
##D beta.prior.mean <- 0
##D beta.prior.precision <- 0
##D 
##D m.4 <-
##D   bayes.geostat.exact(Y~1, data=FORMGMT.dat,
##D                       n.samples=n.samples,
##D                       beta.prior.mean=beta.prior.mean,
##D                       beta.prior.precision=beta.prior.precision,
##D                       coords=coords, phi=phi, alpha=alpha,
##D                       sigma.sq.prior.shape=sigma.sq.prior.shape,
##D                       sigma.sq.prior.rate=sigma.sq.prior.rate,
##D                       sp.effects=FALSE)
##D 
##D print(sp.DIC(m.4, DIC.marg=TRUE, DIC.unmarg=FALSE))
##D 
##D ##Lower DIC is better, so go with the covariates.
##D 
##D ###########################################
##D ##         DIC for ggt.sp
##D ###########################################
##D data(FBC07.dat)
##D 
##D Y.2 <- FBC07.dat[1:100,"Y.2"]
##D coords <- as.matrix(FBC07.dat[1:100,c("coord.X", "coord.Y")])
##D 
##D ##m.5 some model with ggt.sp.
##D K.prior <- prior(dist="IG", shape=2, scale=5)
##D Psi.prior <- prior(dist="IG", shape=2, scale=5)
##D phi.prior <- prior(dist="UNIF", a=0.06, b=3)
##D 
##D var.update.control <-
##D   list("K"=list(starting=5, tuning=0.1, prior=K.prior),
##D        "Psi"=list(starting=5, tuning=0.1, prior=Psi.prior),
##D        "phi"=list(starting=0.1, tuning=0.5, prior=phi.prior)
##D        )
##D 
##D beta.control <- list(update="GIBBS", prior=prior(dist="FLAT"))
##D 
##D run.control <- list("n.samples"=1000, "sp.effects"=TRUE)
##D 
##D m.5 <-
##D   ggt.sp(formula=Y.2~1, run.control=run.control,
##D          coords=coords, var.update.control=var.update.control,
##D          beta.update.control=beta.control,
##D          cov.model="exponential")
##D 
##D ##Now with the ggt.sp object, m.5, calculate the DIC
##D ##for both the unmarginalized and marginalized models.
##D ##The likelihoods for these models are given by equation 6 and 7
##D ##within the vignette.
##D 
##D DIC <- sp.DIC(m.5)
##D print(DIC)
## End(Not run)



